@@ -6,16 +6,17 @@ use strict;
 
 use Exporter;
 
-$Locale::Currency::Format::VERSION = '1.33';
+$Locale::Currency::Format::VERSION = '1.34';
 
 @Locale::Currency::Format::ISA     = qw(Exporter);
 @Locale::Currency::Format::EXPORT  = qw(
     currency_format
+    currency_name
+    currency_set
     currency_symbol
     decimal_precision
     decimal_separator
     thousands_separator
-    currency_set
     FMT_NOZEROS
     FMT_STANDARD
     FMT_COMMON
@@ -57,6 +58,7 @@ my ($name, $frac_len, $thou_sep, $dec_sep,
 
 my %original;
 my %currency;
+my @currency_codes;
 
 *::_error = \$Locale::Currency::Format::error; 
 
@@ -136,6 +138,32 @@ sub currency_symbol {
     return $sym;
 }
 
+sub currency_name {
+    my ( $code ) = @_;
+
+    if ( !defined $code ) {
+        $::_error = 'Undefined currency code';
+        return;
+    }
+
+    my $cur = $currency{ uc $code };
+    if ( !$cur ) {
+        $::_error = 'Invalid currency code';
+        return;
+    }
+
+    my $name =  $cur->[0];
+    if ( !$name ) {
+        $::_error = 'Non-existant currency name';
+        return;
+    }
+    return $name;
+}
+
+sub currency_list {
+    return \@currency_codes;
+}
+
 sub decimal_precision {
     my ($code) = @_;
 
@@ -229,6 +257,7 @@ sub currency_set {
 
     if (!$tmpl) {
         $currency{$ucc} = $original{$ucc} if $original{$ucc};
+        @currency_codes = keys %currency;
         return $ucc;
     }
 
@@ -270,6 +299,7 @@ sub currency_set {
             $cur->[$com_sym] = $2;    
         }
     }
+    @currency_codes = keys %currency;
     return $ucc;
 }
 
@@ -537,7 +567,7 @@ ZMK => ["Kwacha",0,$EMPTY,$EMPTY,"",$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 ZRN => ["New Zaire",$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY,$EMPTY],
 ZWD => ["Zimbabwe Dollar ",2," ",".","","\x{0024}","&#x0024;","Z\$",1],
 );
-
+@currency_codes = keys %currency;
 
 1;
 
@@ -641,6 +671,14 @@ Default is a Unicode-based character. Upon failure, it returns I<undef> and an e
 		 character
         SYM_HTML returns the symbol (if exists) as a HTML escape
 
+=item C<currency_name(CODE)>
+
+For conveniences, the function B<currency_name> is provided for currency name
+lookup given a 3-letter currency code. Upon failure, it returns I<undef> and an error message is stored in B<$Locale::Currency::Format::error>.
+
+    CODE
+        A 3-letter currency code as specified in ISO 4217
+
 =item C<decimal_precision(CODE)>
 
 For conveniences, the function B<decimal_precision> is provided to lookup the decimal
